@@ -211,7 +211,13 @@ class ToxEnv(ABC):
             "LANGUAGE",  # localization
             "CURL_CA_BUNDLE",  # curl certificates
             "SSL_CERT_FILE",  # https certificates
+            "CC",  # C compiler command
+            "CFLAGS",  # C compiler flags
+            "CCSHARED",  # compiler flags used to build a shared library
+            "CXX",  # C++ compiler command
+            "CPPFLAGS",  # C++ compiler flags
             "LD_LIBRARY_PATH",  # location of libs
+            "LDFLAGS",  # linker flags
         ]
         if sys.stdout.isatty():  # if we're on a interactive shell pass on the TERM
             env.append("TERM")
@@ -288,6 +294,7 @@ class ToxEnv(ABC):
             if eq is False and old is not None:  # pragma: no branch  # recreate if already created and not equals
                 raise Recreate(f"env type changed from {old} to {conf}")
         self._handle_env_tmp_dir()
+        self._handle_core_tmp_dir()
 
     def _setup_with_env(self) -> None:  # noqa: B027 # empty abstract base class
         pass
@@ -303,6 +310,9 @@ class ToxEnv(ABC):
             ensure_empty_dir(env_tmp_dir)
         env_tmp_dir.mkdir(parents=True, exist_ok=True)
 
+    def _handle_core_tmp_dir(self) -> None:
+        self.core["temp_dir"].mkdir(parents=True, exist_ok=True)
+
     def _clean(self, transitive: bool = False) -> None:  # noqa: U100
         if self._run_state["clean"]:  # pragma: no branch
             return  # pragma: no cover
@@ -440,7 +450,7 @@ class ToxEnv(ABC):
 
     @staticmethod
     def _write_execute_log(env_name: str, log_file: Path, request: ExecuteRequest, status: ExecuteStatus) -> None:
-        with log_file.open("wt") as file:
+        with log_file.open("wt", encoding="utf-8") as file:
             file.write(f"name: {env_name}\n")
             file.write(f"run_id: {request.run_id}\n")
             for env_key, env_value in request.env.items():
