@@ -171,3 +171,11 @@ def test_set_env_raises_on_non_str(mocker: MockerFixture) -> None:
     env_set.loaders.insert(0, MemoryLoader(set_env=1))
     with pytest.raises(TypeError, match="1"):
         assert env_set["set_env"]
+
+
+@pytest.mark.parametrize("work_dir", ["a", ""])
+def test_config_work_dir(tox_project: ToxProjectCreator, work_dir: str) -> None:
+    project = tox_project({"tox.ini": "[tox]\ntoxworkdir=b"})
+    result = project.run("c", *(["--workdir", str(project.path / work_dir)] if work_dir else []))
+    expected = project.path / work_dir if work_dir else Path("b")
+    assert expected == result.state.conf.core["work_dir"]
