@@ -99,6 +99,14 @@ def test_show_config_exception(tox_project: ToxProjectCreator) -> None:
     assert txt in outcome.out
 
 
+def test_show_config_empty_install_command_exception(tox_project: ToxProjectCreator) -> None:
+    project = tox_project({"tox.ini": "[testenv:a]\ninstall_command="})
+    outcome = project.run("c", "-e", "a", "-k", "install_command")
+    outcome.assert_success()
+    txt = "\ninstall_command = # Exception: " "ValueError(\"attempting to parse '' into a command failed\")"
+    assert txt in outcome.out
+
+
 @pytest.mark.parametrize("stdout_is_atty", [True, False])
 def test_pass_env_config_default(tox_project: ToxProjectCreator, stdout_is_atty: bool, mocker: MockerFixture) -> None:
     mocker.patch("sys.stdout.isatty", return_value=stdout_is_atty)
@@ -107,10 +115,11 @@ def test_pass_env_config_default(tox_project: ToxProjectCreator, stdout_is_atty:
     pass_env = outcome.env_conf("py")["pass_env"]
     is_win = sys.platform == "win32"
     expected = (
-        (["COMSPEC"] if is_win else [])
-        + ["CURL_CA_BUNDLE", "LANG", "LANGUAGE", "LD_LIBRARY_PATH"]
+        ["CC", "CCSHARED", "CFLAGS"]
+        + (["COMSPEC"] if is_win else [])
+        + ["CPPFLAGS", "CURL_CA_BUNDLE", "CXX", "LANG", "LANGUAGE", "LDFLAGS", "LD_LIBRARY_PATH"]
         + (["MSYSTEM", "NUMBER_OF_PROCESSORS", "PATHEXT"] if is_win else [])
-        + ["PIP_*", "PKG_CONFIG_PATH"]
+        + ["PIP_*", "PKG_CONFIG", "PKG_CONFIG_PATH", "PKG_CONFIG_SYSROOT_DIR"]
         + (["PROCESSOR_ARCHITECTURE"] if is_win else [])
         + (["PROGRAMDATA"] if is_win else [])
         + (["PROGRAMFILES"] if is_win else [])
@@ -246,3 +255,20 @@ def test_show_config_matching_env_section(tox_project: ToxProjectCreator) -> Non
     outcome = project.run("c", "-e", "a,b", "-k", "deps")
     outcome.assert_success()
     assert outcome.out.count("c>=1") == 2, outcome.out
+
+
+def test_package_env_inherits_from_pkgenv(tox_project: ToxProjectCreator, demo_pkg_inline: Path) -> None:
+    project = tox_project({"tox.ini": "[pkgenv]\npass_env = A, B\ndeps=C\n D"})
+    outcome = project.run("c", "--root", str(demo_pkg_inline), "-k", "deps", "pass_env", "-e", "py,.pkg")
+    outcome.assert_success()
+    exp = """
+    [testenv:.pkg]
+    deps =
+      C
+      D
+    pass_env =
+      A
+      B
+    """
+    exp = dedent(exp)
+    assert exp in outcome.out
